wlan: Enterprise Security Enhancements

A proper nomenclature is being put in place, to make
the code reflect the appropriate functionality
that is associated with it.

Change-Id: I3e0c869a1259b77c4e692fe02f93cbcef9001104
CRs-Fixed: 622164
(cherry picked from commit 39aef9ead739f8574c2e88a2465f81e2091174a3)
diff --git a/CORE/TL/inc/wlan_qct_tl.h b/CORE/TL/inc/wlan_qct_tl.h
index e9ada2f..33fe42d 100644
--- a/CORE/TL/inc/wlan_qct_tl.h
+++ b/CORE/TL/inc/wlan_qct_tl.h
@@ -270,9 +270,9 @@
  /*Flag to indicate if STA is a WAPI STA*/
   v_U8_t         ucIsWapiSta;
 
-#ifdef FEATURE_WLAN_CCX
- /*Flag to indicate if STA is a CCX STA*/
-  v_U8_t         ucIsCcxSta;
+#ifdef FEATURE_WLAN_ESE
+ /*Flag to indicate if STA is a ESE STA*/
+  v_U8_t         ucIsEseSta;
 #endif
 
   /*DPU Signature used for broadcast data - used for data caching*/